import sys
import typing
from . import view2d
from . import action
from . import import_scene
from . import object
from . import marker
from . import safe_areas
from . import workspace
from . import gpencil
from . import texture
from . import sculpt_curves
from . import sequencer
from . import scene
from . import ptcache
from . import world
from . import anim
from . import curve
from . import mask
from . import export_mesh
from . import view3d
from . import info
from . import sound
from . import buttons
from . import text
from . import cycles
from . import surface
from . import node
from . import constraint
from . import lattice
from . import export_anim
from . import script
from . import transform
from . import outliner
from . import cachefile
from . import dpaint
from . import collection
from . import particle
from . import file
from . import export_scene
from . import curves
from . import cloth
from . import spreadsheet
from . import paintcurve
from . import uv
from . import brush
from . import material
from . import palette
from . import rigidbody
from . import poselib
from . import nla
from . import import_anim
from . import armature
from . import geometry
from . import ed
from . import sculpt
from . import ui
from . import screen
from . import fluid
from . import import_mesh
from . import mball
from . import preferences
from . import mesh
from . import asset
from . import gizmogroup
from . import clip
from . import camera
from . import paint
from . import pose
from . import font
from . import console
from . import boid
from . import import_curve
from . import render
from . import graph
from . import image
from . import wm



import sys
import typing


def assign_default_button():
    ''' Set this property's current value as the new default

    '''

    pass


def button_execute(skip_depressed: bool = False):
    ''' Presses active button

    :param skip_depressed: Skip Depressed
    :type skip_depressed: bool
    '''

    pass


def button_string_clear():
    ''' Unsets the text of the active button

    '''

    pass


def copy_as_driver_button():
    ''' Create a new driver with this property as input, and copy it to the clipboard. Use Paste Driver to add it to the target property, or Paste Driver Variables to extend an existing driver

    '''

    pass


def copy_data_path_button(full_path: bool = False):
    ''' Copy the RNA data path for this property to the clipboard

    :param full_path: full_path, Copy full data path
    :type full_path: bool
    '''

    pass


def copy_python_command_button():
    ''' Copy the Python command matching this button

    '''

    pass


def copy_to_selected_button(all: bool = True):
    ''' Copy property from this object to selected objects or bones

    :param all: All, Copy to selected all elements of the array
    :type all: bool
    '''

    pass


def drop_color(color: typing.List[float] = (0.0, 0.0, 0.0),
               gamma: bool = False):
    ''' Drop colors to buttons

    :param color: Color, Source color
    :type color: typing.List[float]
    :param gamma: Gamma Corrected, The source color is gamma corrected
    :type gamma: bool
    '''

    pass


def drop_material(session_uuid: int = 0):
    ''' Drag material to Material slots in Properties

    :param session_uuid: Session UUID, Session UUID of the data-block to assign
    :type session_uuid: int
    '''

    pass


def drop_name(string: str = ""):
    ''' Drop name to button

    :param string: String, The string value to drop into the button
    :type string: str
    '''

    pass


def editsource():
    ''' Edit UI source code of the active button

    '''

    pass


def edittranslation_init():
    ''' Edit i18n in current language for the active button

    '''

    pass


def eyedropper_color():
    ''' Sample a color from the Blender window to store in a property

    '''

    pass


def eyedropper_colorramp():
    ''' Sample a color band

    '''

    pass


def eyedropper_colorramp_point():
    ''' Point-sample a color band

    '''

    pass


def eyedropper_depth():
    ''' Sample depth from the 3D view

    '''

    pass


def eyedropper_driver(mapping_type: typing.Union[str, int] = 'SINGLE_MANY'):
    ''' Pick a property to use as a driver target

    :param mapping_type: Mapping Type, Method used to match target and driven properties * SINGLE_MANY All from Target -- Drive all components of this property using the target picked. * DIRECT Single from Target -- Drive this component of this property using the target picked. * MATCH Match Indices -- Create drivers for each pair of corresponding elements. * NONE_ALL Manually Create Later -- Create drivers for all properties without assigning any targets yet. * NONE_SINGLE Manually Create Later (Single) -- Create driver for this property only and without assigning any targets yet.
    :type mapping_type: typing.Union[str, int]
    '''

    pass


def eyedropper_gpencil_color(mode: typing.Union[str, int] = 'MATERIAL'):
    ''' Sample a color from the Blender Window and create Grease Pencil material

    :param mode: Mode
    :type mode: typing.Union[str, int]
    '''

    pass


def eyedropper_id():
    ''' Sample a data-block from the 3D View to store in a property

    '''

    pass


def jump_to_target_button():
    ''' Switch to the target object or bone

    '''

    pass


def list_start_filter():
    ''' Start entering filter text for the list in focus

    '''

    pass


def override_remove_button(all: bool = True):
    ''' Remove an override operation

    :param all: All, Reset to default values all elements of the array
    :type all: bool
    '''

    pass


def override_type_set_button(all: bool = True,
                             type: typing.Union[str, int] = 'REPLACE'):
    ''' Create an override operation, or set the type of an existing one

    :param all: All, Reset to default values all elements of the array
    :type all: bool
    :param type: Type, Type of override operation * NOOP NoOp -- 'No-Operation', place holder preventing automatic override to ever affect the property. * REPLACE Replace -- Completely replace value from linked data by local one. * DIFFERENCE Difference -- Store difference to linked data value. * FACTOR Factor -- Store factor to linked data value (useful e.g. for scale).
    :type type: typing.Union[str, int]
    '''

    pass


def reloadtranslation():
    ''' Force a full reload of UI translation

    '''

    pass


def reset_default_button(all: bool = True):
    ''' Reset this property's value to its default value

    :param all: All, Reset to default values all elements of the array
    :type all: bool
    '''

    pass


def tree_view_drop():
    ''' Drag and drop items onto a tree item

    '''

    pass


def tree_view_item_rename():
    ''' Rename the active item in the tree

    '''

    pass


def unset_property_button():
    ''' Clear the property and use default or generated value in operators

    '''

    pass



import sys
import typing


def add():
    ''' Add new cache

    '''

    pass


def bake(bake: bool = False):
    ''' Bake physics

    :param bake: Bake
    :type bake: bool
    '''

    pass


def bake_all(bake: bool = True):
    ''' Bake all physics

    :param bake: Bake
    :type bake: bool
    '''

    pass


def bake_from_cache():
    ''' Bake from cache

    '''

    pass


def free_bake():
    ''' Delete physics bake

    '''

    pass


def free_bake_all():
    ''' Delete all baked caches of all objects in the current scene

    '''

    pass


def remove():
    ''' Delete current cache

    '''

    pass



import sys
import typing


def add_point(location: typing.List[int] = (0, 0)):
    ''' Add New Paint Curve Point

    :param location: Location, Location of vertex in area space
    :type location: typing.List[int]
    '''

    pass


def add_point_slide(PAINTCURVE_OT_add_point=None, PAINTCURVE_OT_slide=None):
    ''' Add new curve point and slide it

    :param PAINTCURVE_OT_add_point: Add New Paint Curve Point, Add New Paint Curve Point
    :param PAINTCURVE_OT_slide: Slide Paint Curve Point, Select and slide paint curve point
    '''

    pass


def cursor():
    ''' Place cursor

    '''

    pass


def delete_point():
    ''' Remove Paint Curve Point

    '''

    pass


def draw():
    ''' Draw curve

    '''

    pass


def new():
    ''' Add new paint curve

    '''

    pass


def select(location: typing.List[int] = (0, 0),
           toggle: bool = False,
           extend: bool = False):
    ''' Select a paint curve point

    :param location: Location, Location of vertex in area space
    :type location: typing.List[int]
    :param toggle: Toggle, (De)select all
    :type toggle: bool
    :param extend: Extend, Extend selection
    :type extend: bool
    '''

    pass


def slide(align: bool = False, select: bool = True):
    ''' Select and slide paint curve point

    :param align: Align Handles, Aligns opposite point handle during transform
    :type align: bool
    :param select: Select, Attempt to select a point handle before transform
    :type select: bool
    '''

    pass



import sys
import typing


def action_pushdown(channel_index: int = -1):
    ''' Push action down onto the top of the NLA stack as a new strip

    :param channel_index: Channel Index, Index of NLA action channel to perform pushdown operation on
    :type channel_index: int
    '''

    pass


def action_sync_length(active: bool = True):
    ''' Synchronize the length of the referenced Action with the length used in the strip

    :param active: Active Strip Only, Only sync the active length for the active strip
    :type active: bool
    '''

    pass


def action_unlink(force_delete: bool = False):
    ''' Unlink this action from the active action slot (and/or exit Tweak Mode)

    :param force_delete: Force Delete, Clear Fake User and remove copy stashed in this data-block's NLA stack
    :type force_delete: bool
    '''

    pass


def actionclip_add(action: typing.Union[str, int] = ''):
    ''' Add an Action-Clip strip (i.e. an NLA Strip referencing an Action) to the active track

    :param action: Action
    :type action: typing.Union[str, int]
    '''

    pass


def apply_scale():
    ''' Apply scaling of selected strips to their referenced Actions

    '''

    pass


def bake(
        frame_start: int = 1,
        frame_end: int = 250,
        step: int = 1,
        only_selected: bool = True,
        visual_keying: bool = False,
        clear_constraints: bool = False,
        clear_parents: bool = False,
        use_current_action: bool = False,
        clean_curves: bool = False,
        bake_types: typing.Union[typing.Set[str], typing.Set[int]] = {'POSE'}):
    ''' Bake all selected objects location/scale/rotation animation to an action

    :param frame_start: Start Frame, Start frame for baking
    :type frame_start: int
    :param frame_end: End Frame, End frame for baking
    :type frame_end: int
    :param step: Frame Step, Frame Step
    :type step: int
    :param only_selected: Only Selected Bones, Only key selected bones (Pose baking only)
    :type only_selected: bool
    :param visual_keying: Visual Keying, Keyframe from the final transformations (with constraints applied)
    :type visual_keying: bool
    :param clear_constraints: Clear Constraints, Remove all constraints from keyed object/bones, and do 'visual' keying
    :type clear_constraints: bool
    :param clear_parents: Clear Parents, Bake animation onto the object then clear parents (objects only)
    :type clear_parents: bool
    :param use_current_action: Overwrite Current Action, Bake animation into current action, instead of creating a new one (useful for baking only part of bones in an armature)
    :type use_current_action: bool
    :param clean_curves: Clean Curves, After baking curves, remove redundant keys
    :type clean_curves: bool
    :param bake_types: Bake Data, Which data's transformations to bake * POSE Pose -- Bake bones transformations. * OBJECT Object -- Bake object transformations.
    :type bake_types: typing.Union[typing.Set[str], typing.Set[int]]
    '''

    pass


def channels_click(extend: bool = False):
    ''' Handle clicks to select NLA channels

    :param extend: Extend Select
    :type extend: bool
    '''

    pass


def clear_scale():
    ''' Reset scaling of selected strips

    '''

    pass


def click_select(wait_to_deselect_others: bool = False,
                 mouse_x: int = 0,
                 mouse_y: int = 0,
                 extend: bool = False,
                 deselect_all: bool = False):
    ''' Handle clicks to select NLA Strips

    :param wait_to_deselect_others: Wait to Deselect Others
    :type wait_to_deselect_others: bool
    :param mouse_x: Mouse X
    :type mouse_x: int
    :param mouse_y: Mouse Y
    :type mouse_y: int
    :param extend: Extend Select
    :type extend: bool
    :param deselect_all: Deselect On Nothing, Deselect all when nothing under the cursor
    :type deselect_all: bool
    '''

    pass


def delete():
    ''' Delete selected strips

    '''

    pass


def duplicate(linked: bool = False,
              mode: typing.Union[str, int] = 'TRANSLATION'):
    ''' Duplicate selected NLA-Strips, adding the new strips in new tracks above the originals

    :param linked: Linked, When duplicating strips, assign new copies of the actions they use
    :type linked: bool
    :param mode: Mode
    :type mode: typing.Union[str, int]
    '''

    pass


def fmodifier_add(type: typing.Union[str, int] = 'NULL',
                  only_active: bool = True):
    ''' Add F-Modifier to the active/selected NLA-Strips

    :param type: Type * NULL Invalid. * GENERATOR Generator -- Generate a curve using a factorized or expanded polynomial. * FNGENERATOR Built-In Function -- Generate a curve using standard math functions such as sin and cos. * ENVELOPE Envelope -- Reshape F-Curve values, e.g. change amplitude of movements. * CYCLES Cycles -- Cyclic extend/repeat keyframe sequence. * NOISE Noise -- Add pseudo-random noise on top of F-Curves. * LIMITS Limits -- Restrict maximum and minimum values of F-Curve. * STEPPED Stepped Interpolation -- Snap values to nearest grid step, e.g. for a stop-motion look.
    :type type: typing.Union[str, int]
    :param only_active: Only Active, Only add a F-Modifier of the specified type to the active strip
    :type only_active: bool
    '''

    pass


def fmodifier_copy():
    ''' Copy the F-Modifier(s) of the active NLA-Strip

    '''

    pass


def fmodifier_paste(only_active: bool = True, replace: bool = False):
    ''' Add copied F-Modifiers to the selected NLA-Strips

    :param only_active: Only Active, Only paste F-Modifiers on active strip
    :type only_active: bool
    :param replace: Replace Existing, Replace existing F-Modifiers, instead of just appending to the end of the existing list
    :type replace: bool
    '''

    pass


def make_single_user():
    ''' Ensure that each action is only used once in the set of strips selected

    '''

    pass


def meta_add():
    ''' Add new meta-strips incorporating the selected strips

    '''

    pass


def meta_remove():
    ''' Separate out the strips held by the selected meta-strips

    '''

    pass


def move_down():
    ''' Move selected strips down a track if there's room

    '''

    pass


def move_up():
    ''' Move selected strips up a track if there's room

    '''

    pass


def mute_toggle():
    ''' Mute or un-mute selected strips

    '''

    pass


def previewrange_set():
    ''' Set Preview Range based on extends of selected strips

    '''

    pass


def select_all(action: typing.Union[str, int] = 'TOGGLE'):
    ''' Select or deselect all NLA-Strips

    :param action: Action, Selection action to execute * TOGGLE Toggle -- Toggle selection for all elements. * SELECT Select -- Select all elements. * DESELECT Deselect -- Deselect all elements. * INVERT Invert -- Invert selection of all elements.
    :type action: typing.Union[str, int]
    '''

    pass


def select_box(axis_range: bool = False,
               tweak: bool = False,
               xmin: int = 0,
               xmax: int = 0,
               ymin: int = 0,
               ymax: int = 0,
               wait_for_input: bool = True,
               mode: typing.Union[str, int] = 'SET'):
    ''' Use box selection to grab NLA-Strips

    :param axis_range: Axis Range
    :type axis_range: bool
    :param tweak: Tweak, Operator has been activated using a click-drag event
    :type tweak: bool
    :param xmin: X Min
    :type xmin: int
    :param xmax: X Max
    :type xmax: int
    :param ymin: Y Min
    :type ymin: int
    :param ymax: Y Max
    :type ymax: int
    :param wait_for_input: Wait for Input
    :type wait_for_input: bool
    :param mode: Mode * SET Set -- Set a new selection. * ADD Extend -- Extend existing selection. * SUB Subtract -- Subtract existing selection.
    :type mode: typing.Union[str, int]
    '''

    pass


def select_leftright(mode: typing.Union[str, int] = 'CHECK',
                     extend: bool = False):
    ''' Select strips to the left or the right of the current frame

    :param mode: Mode
    :type mode: typing.Union[str, int]
    :param extend: Extend Select
    :type extend: bool
    '''

    pass


def selected_objects_add():
    ''' Make selected objects appear in NLA Editor by adding Animation Data

    '''

    pass


def snap(type: typing.Union[str, int] = 'CFRA'):
    ''' Move start of strips to specified time

    :param type: Type
    :type type: typing.Union[str, int]
    '''

    pass


def soundclip_add():
    ''' Add a strip for controlling when speaker plays its sound clip

    '''

    pass


def split():
    ''' Split selected strips at their midpoints

    '''

    pass


def swap():
    ''' Swap order of selected strips within tracks

    '''

    pass


def tracks_add(above_selected: bool = False):
    ''' Add NLA-Tracks above/after the selected tracks

    :param above_selected: Above Selected, Add a new NLA Track above every existing selected one
    :type above_selected: bool
    '''

    pass


def tracks_delete():
    ''' Delete selected NLA-Tracks and the strips they contain

    '''

    pass


def transition_add():
    ''' Add a transition strip between two adjacent selected strips

    '''

    pass


def tweakmode_enter(isolate_action: bool = False,
                    use_upper_stack_evaluation: bool = False):
    ''' Enter tweaking mode for the action referenced by the active strip to edit its keyframes

    :param isolate_action: Isolate Action, Enable 'solo' on the NLA Track containing the active strip, to edit it without seeing the effects of the NLA stack
    :type isolate_action: bool
    :param use_upper_stack_evaluation: Evaluate Upper Stack, In tweak mode, display the effects of the tracks above the tweak strip
    :type use_upper_stack_evaluation: bool
    '''

    pass


def tweakmode_exit(isolate_action: bool = False):
    ''' Exit tweaking mode for the action referenced by the active strip

    :param isolate_action: Isolate Action, Disable 'solo' on any of the NLA Tracks after exiting tweak mode to get things back to normal
    :type isolate_action: bool
    '''

    pass


def view_all():
    ''' Reset viewable area to show full strips range

    '''

    pass


def view_frame():
    ''' Move the view to the current frame

    '''

    pass


def view_selected():
    ''' Reset viewable area to show selected strips range

    '''

    pass
